/* Help make file for MakeFSA
 *
 * Author: Dylan Muir (dr.muir@student.qut.edu.au
 * Date: 4th October, 1999
 * Modified: 13th September, 2000
 * Version: 0.02
 */

#define p(x)	fprintf(helpFile, x);

p("\n");
p("This program creates a deterministic FSA from a set of state definitions\n");
p("(clustering codebook) and a set of training vectors.  This is used to obtain an\n");
p("FSA from a tlearn hidden units probe run and an AVQ (Euclidean distance or correlation\n");
p("distance) analysis of the hidden unit states.\n");
p("\n");
p("MakeFSA will generate a state for each cluster in the AVQ analysis.  The\n");
p("training vectors will be read and a transition table generated from state to\n");
p("state given each input.  Non-deterministic transitions are culled by taking\n");
p("the most probable state moved to for each input, as well as the most probable\n");
p("output for each transition.\n");
p("\n");
p("The FSA definition is augmented by a start state and a rescue state, as well as\n");
p("a rescue output.  These are defined as:\n");
p(" o Start state: the state corresponding to the cluster containing the zero\n");
p("   vector.\n");
p(" o Rescue state: at this stage, this is the same as the start state.\n");
p(" o Rescue output: the most common output for all inputs (i.e. a noun in\n");
p("   language data).\n");
p("\n");
p("Inputs are:\n");
p(" o The type of clustering that was performed (spherical or elliptical).\n");
p(" o A file corresponding to the clusters identified by the AVQ analysis.\n");
p(" o A pattern file with a list of input/output pairs for the training data.\n");
p(" o A file of vectors containing the training data (hidden unit activations)\n");
p(" o An optional file specifing names ('tags') to give to each of the\n");
p("   intput / output lines (tags file).\n");
p("\n");
p("\n");
p("Input formats:\n");
p("Vector files(k-means clusters, training set):\n");
p(" o Vectors are input one per line.\n");
p(" o Vector components are separated by whitespace (space or tab).\n");
p(" o All vectors in the file should be of the same dimensionality.\n");
p("\n");
p("Codebook file:\n");
p(" o For k-means clusters, see above.\n");
p(" o For o2clust clusters, the file format is determined by CMatrixWrite in the");
p("   corr_matrix.c source file.\n");
p("\n");
p("Pattern file:\n");
p(" o each line follows the same pattern: input# intput output.\n");
p(" o input# starts from zero and counts up to the number of inputs.\n");
p(" o input and output represent the input and output lines that should be\n");
p("   activated.\n");
p("\n");
p("Tags file:\n");
p(" o Tags are separated by whitespace (space, tab or <cr>).\n");
p(" o If this file is given, there MUST be at least as many tags as input / output\n");
p("   lines.  The program's behavious is undefined otherwise.\n");
p("\n");
p("\n");
p("Output formats:\n");
p("FSA Definition:\n");
p(" o The output format is designed to be used in Ingo Schellhammer's FSA\n");
p("   simulator 'autosim'.  It consists of an explicit header which must be\n");
p("   character perfect, containing the start state, rescue state and rescue\n");
p("   output.\n");
p(" o Deterministic FSA transitions are given one per line, separated by commas.\n");
p(" o If a tags file was specifed, inputs and outputs are translated into tags.\n");
p("   (Note that this format is not compatible with 'autosim').\n");
p("\n");
p("\n");
p("Note: MakeFSA was designed for use on an elman-type recurrent neural network\n");
p("      trained on language data to perform a one-step-lookahead task.  Therefore\n");
p("      the input and output lines correspond one-to-one, and the tags file can\n");
p("      be used to describe both.  This should hold true for most FSAs. The\n");
p("      pattern files used were generated by concatenating lines in tlearn\n");
p("      ___.teach and ___.data files.  This will only work if the tlearn files\n");
p("      are in locallist format.\n");
p("\n");
p("\n");
p("\n");
p("\n");

#undef p

/* --- END of generic.help.make --- */


